import 'dart:async';
import 'package:flutter/material.dart';

import 'package:app_state/app_state.dart';

import 'package:q/data/app/appstate.dart';
import 'package:q/ui/app/app.dart';
import 'package:q/ui/app/route/app_state_ext.dart';
import 'package:q/ui/welcome/welcome_screen.dart';

const String splashFactoryKey = 'Splash';
const String splashUrl = '/splash';

class SplashPagePath extends PagePath {
  static const _location = splashUrl;

  const SplashPagePath() : super(key: splashFactoryKey);

  @override
  String get location => _location;
}

class SplashPage extends StatelessMaterialPage {
  static const classFactoryKey = splashFactoryKey;

  SplashPage()
      : super(
          key: const ValueKey(splashFactoryKey),
          child: const SplashScreen(),
          factoryKey: splashFactoryKey,
          path: const SplashPagePath(),
        );
}

class SplashScreen extends StatefulWidget {
  const SplashScreen({super.key});

  @override
  State<SplashScreen> createState() => _SplashScreenState();
}

class _SplashScreenState extends State<SplashScreen> {
  final AppState appState = AppState();

  bool _initialized = false;

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();

    if (!_initialized) {
      _initialized = true;

      Timer(const Duration(milliseconds: 3000), () {
        appState.splashFinished();

        //pageStack.go(const WelcomePagePath());
        pageStack.replacePath(const WelcomePagePath());
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: const Color(0xFF1E2429),
      body: Container(
        width: double.infinity,
        height: double.infinity,
        decoration: BoxDecoration(
          image: DecorationImage(
            fit: BoxFit.cover,
            image: Image.asset(
              'assets/images/splash.png',
            ).image,
          ),
        ),
        child: Padding(
          padding: const EdgeInsetsDirectional.fromSTEB(50, 50, 50, 50),
          child: Column(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.end,
            children: const [
              Padding(
                padding: EdgeInsetsDirectional.fromSTEB(0, 24, 0, 0),
                child: Text(
                  'Hello!',
                  style: TextStyle(
                      //should this be pulled from the theme, yes, but need to learn the best way to do.
                      fontFamily: 'Roboto',
                      color: Colors.white,
                      fontSize: 28,
                      fontWeight: FontWeight.w500),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
