import 'package:flutter/material.dart';

import 'package:app_state/app_state.dart';

const String welcomeFactoryKey = 'Start';
const String welcomeUrl = '/welcome';

class WelcomePagePath extends PagePath {
  static const _location = welcomeUrl;

  const WelcomePagePath() : super(key: welcomeFactoryKey);

  @override
  String get location => _location;
}

class WelcomePage extends StatelessMaterialPage {
  static const classFactoryKey = welcomeFactoryKey;

  WelcomePage()
      : super(
          key: const ValueKey(welcomeFactoryKey),
          factoryKey: welcomeFactoryKey,
          child: const WelcomeScreen(),
          path: const WelcomePagePath(),
        );
}

class WelcomeScreen extends StatelessWidget {
  const WelcomeScreen({super.key});

  void doPhoneAuth() {}

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        elevation: 0,
        backgroundColor: Theme.of(context).primaryColor,
        flexibleSpace: const Padding(
          padding: EdgeInsetsDirectional.fromSTEB(0, 16, 0, 0),
          child: Text(
            'Welcome',
            textAlign: TextAlign.center,
            style: TextStyle(
                fontFamily: 'Roboto', color: Colors.white, fontSize: 22),
          ),
        ),
      ),
      body: SafeArea(
        child: GestureDetector(
          onTap: () => FocusScope.of(context).unfocus(),
          child: Align(
            alignment: const AlignmentDirectional(0, 0),
            child: Column(
              mainAxisSize: MainAxisSize.max,
              children: [
                Padding(
                  padding: const EdgeInsetsDirectional.fromSTEB(0, 100, 0, 0),
                  child: Image.asset(
                    'assets/images/welcome.png',
                    width: 200,
                    height: 200,
                    fit: BoxFit.fill,
                  ),
                ),
                const Padding(
                  padding: EdgeInsetsDirectional.fromSTEB(0, 40, 0, 50),
                  child: Text(
                    'Welcome!',
                    textAlign: TextAlign.center,
                    style: TextStyle(
                        fontFamily: 'Roboto',
                        fontSize: 24,
                        fontWeight: FontWeight.w300),
                  ),
                ),
                Padding(
                  padding: const EdgeInsetsDirectional.fromSTEB(0, 0, 0, 0),
                  child: ElevatedButton(
                    style: ElevatedButton.styleFrom(
                      backgroundColor: Theme.of(context).primaryColor,
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(12.0),
                      ),
                      side: BorderSide(color: Theme.of(context).primaryColor),
                      fixedSize: const Size(130, 40),
                      maximumSize: const Size(130, 40),
                    ),
                    onPressed: doPhoneAuth,
                    child: const Text(
                      'Get Started',
                      style: TextStyle(color: Colors.white),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
